
*****************************************************************
**** SET UP THE EU LMP PROGRAM DATASET (v 1807) FOR ANALYSIS ****
*****************************************************************

** When making use of the EU LMP Program Dataset, please cite the article for which it was first prepared
   ** Cronert, A. (forthcoming) “Unemployment reduction or labor force expansion? How partisanship matters for the design of active labor market policy in Europe”. Socio-Economic Review, available at https://doi.org/10.1093/ser/mwx014.

** as well as the original source of the data
   ** European Commission (2015) The labour market policy (LMP) database <http://ec.europa.eu/eurostat/web/labour-market/labour-market-policy>.

*****************************************************************
***************** NOTE ON THE UNITS OF ANALYSIS *****************
*****************************************************************

** Note that the unit of analysis (row) in the EU LMP Program Dataset is not intervention-year (geoint_year) but intervention-component-year (geo_class_geoint_year).
** This is because several LMP programs contain expenditure and/or participants that are classified by Eurostat as different types of action.

** As an example, the Job and Development Programme in Sweden (geoint = SE70) contains labor market service component in category 1.1 (geo_class_geoint = SE_11_SE70_1), 
** a training component in category 2.1 (geo_class_geoint_year = SE_21_SE70_2), an employment incentive component in category 4.1 (geo_class_geoint_year = SE_41_SE70_3),
** a rehabilitation component in category 5.2 (geo_class_geoint_year = SE_52_SE70_4) and a start-up incentive component in category 7 (geo_class_geoint_year = SE_7_SE70_5)
** Each of these program-components form a separate panel in the panel dataset as set up below. 
** To attain program-year data, use the -collapse [...], by(geoint year)- command to collapse data across program components in the same program. 

*****************************************************************
****************** 1. SET UP WORKING DIRECTORY ******************
*****************************************************************

** Set as working directory a folder that contains the following four .dta files:
** ELPD_exp_v1807.dta
** ELPD_part_v1807.dta
** ELPD_qual_v1807.dta
** ELPD_ccode_year_v1807.dta
cd "[...your working directory]"

*****************************************************************
********************* 2. MERGE THE DATASETS *********************
*****************************************************************

** 2.1 Load the dataset with expenditure program-component-year observations
use "ELPD_exp_v1807.dta", clear

** 2.2 Merge with participant program-component observations on the panel-year variable geo_class_geoint_year. 
**     Drop participant program-component panels that are not matched to the expenditure program-component panels, 
**     most of which 1) are adjustment components or 2) contain no actual participant data.
merge 1:1 geo_class_geoint_year using "ELPD_part_v1807.dta"
drop if _merge == 2
drop _merge

** 2.3 Merge with qualitative program data on the program-year variable geoint_year. 
**     Drop programs that are included in the qualitative reports even though they have no reported expenditure or participant data.
merge m:1 geoint_year using "ELPD_qual_v1807.dta"
drop if _merge == 2
drop _merge

merge m:1 ccode_year using "ELPD_ccode_year_v1807.dta", keepusing(eu_gdpcur_mio_eur eu_gdpcur_mio_nac eu_priceindex_eur2005_100)
drop if _merge ==2
drop _merge

** 2.4 Order the variables according to the EU LMP Program Database Variable Description
order geo country ccode ccode_year year ccode_firstyear ccode_lastyear eu_gdpcur_mio_eur eu_gdpcur_mio_nac eu_priceindex_eur2005_100 geoint geoint_year  geo_class_geoint panel_id mixed_intervention mixed_component_id class_comp2d class_comp1d adjustment geo_class_geoint_year iv*, first

** 2.5 In the raw data, each program-component contains one row for each of the total 16 years (1998-2013), 
**     regardless of which year(s) the program has actually been reported.
**     To exclude empty observations, drop each program-component-year for which the program has not been reported. 
**     Use a variable for which data are complete, such as the program name (iv2_1_name_en).
drop if iv2_1name_en == ""

** 2.6 Declare data to be program-component panels with yearly observations. 
**     Panel_id is a numeric version of the program-component indicator geo_class_geoint
xtset panel_id year

** 2.7 Save the dataset. 
save "EU_LMP_Program_Dataset_v1807.dta", replace


